@@ -41,9 +41,9 @@ class Blueprint(metaclass=BlueprintMeta):
     def __init__(self, name=None, url_prefix='/', host='.*', strict_slashes=False):
         self.name = name
         self.host = host
+        self.rules = []
         self.url_prefix = url_prefix
         self.strict_slashes = strict_slashes
-        self.rules = []
         self.events = collections.defaultdict(list)
         self.blueprints.append(self)
 
@@ -53,6 +53,8 @@ class Blueprint(metaclass=BlueprintMeta):
             rule_name = name or handler.__name__
             if self.name:
                 rule_name = f'{self.name}.{rule_name}'
+            if rule_name in [x[-1] for x in self.rules]:
+                rule_name = None
             rule_uri = self.url_prefix.rstrip('/') + uri
             self.rules.append((rule_uri, handler, params, rule_name))
             if not self.strict_slashes and rule_uri.endswith('/'):
@@ -123,11 +125,9 @@ class Application(Blueprint):
         self.logger.info('shutting down')
         tasks = [task for task in asyncio.Task.all_tasks() if task is not
                  asyncio.tasks.Task.current_task()]
+        self.logger.warning(f'canceling {len(tasks)} pending tasks')
         if tasks:
-            self.logger.warning(f'canceling {len(tasks)} pending tasks')
-            await asyncio.sleep(1)
-            task = asyncio.gather(*tasks, return_exceptions=True)
-            task.cancel()
+            asyncio.gather(*tasks, return_exceptions=True).cancel()
 
         self.ioloop.stop()
 
