@@ -122,7 +122,6 @@ class LogoutHandler(BaseHandler):
 
     def get(self):
         self.clear_cookie('token')
-        self.clear_cookie('user_token')
         self.redirect('/')
 
 
@@ -134,36 +133,39 @@ class SignupHandler(BaseHandler):
         self.render('signup.html')
 
     async def post(self):
-        username = self.get_argument('username', None)
-        password = self.get_argument('password', None)
-        email = self.get_argument('email', None)
-
         ret = await self.check_username()
         if ret.err:
             return self.finish(ret)
-
         ret = await self.check_email()
         if ret.err:
             return self.finish(ret)
+        if self.args.code:
+            ret = await self.check_code()
+            if ret.err:
+                return self.finish(ret)
+            self.args.pop('code')
 
-        if username and password and email:
+        if self.args.username and self.args.password and self.args.email:
             token = uuid.uuid4().hex
-            seq_id = await awaitable(self.db.users.seq_id)
             doc = self.args.copy()
             doc.update({
-                'id': seq_id,
-                'username': username,
-                'password': self.encrypt(password),
-                'email': email,
+                'password': self.encrypt(self.args.password),
                 'token': token,
                 'created_at': datetime.datetime.now().replace(microsecond=0)
             })
-            if doc.get('id') == 1:
-                doc.admin = True
-            await awaitable(self.db.users.insert_one(doc))
+            ret = await awaitable(self.db.users.find_one_and_update({'username': doc['username']},
+                                                                    {'$set': doc},
+                                                                    upsert=True,
+                                                                    return_document=True))
+            update = {}
+            if not ret.id:
+                update['id'] = await awaitable(self.db.users.seq_id)
+                if update['id'] == 1:
+                    update['admin'] = True
+            if update:
+                await awaitable(self.db.users.update_one({'_id': ret._id}, {'$set': update}))
             self.set_cookie('token', token, expires_days=30)
             self.finish({'err': 0})
-            # await self.app.http.get(f'https://{self.request.host}/email/active', params={'email': email})
         else:
             self.finish({'err': 1, 'msg': '信息未填写完整'})
 
@@ -181,10 +183,10 @@ class SigninHandler(BaseHandler):
         remember = self.get_argument('remember', None)
         if username and password:
             if username.find('@') >= 0:
-                doc = {'email': username, 'password': self.encrypt(password)}
+                query = {'email': username, 'password': self.encrypt(password)}
             else:
-                doc = {'username': username, 'password': self.encrypt(password)}
-            user = await awaitable(self.db.users.find_one(doc))
+                query = {'username': username, 'password': self.encrypt(password)}
+            user = await awaitable(self.db.users.find_one(query))
             if user:
                 ret = {'err': 0, 'msg': '登录成功'}
                 if remember == 'on':
@@ -202,7 +204,7 @@ class SigninHandler(BaseHandler):
 class UserHandler(BaseHandler):
 
     async def get(self):
-        user = await awaitable(self.current_user)
+        user = self.current_user
         if user:
             user = dict([(k, v) for k, v in user.items() if k not in ['token', 'password', '_id']])
             self.finish(user)
@@ -211,7 +213,7 @@ class UserHandler(BaseHandler):
 
     @tornado.web.authenticated
     async def post(self):
-        user = await awaitable(self.current_user)
+        user = self.current_user
         old_password = self.get_argument('old_password', None)
         password = self.get_argument('password', None)
         if not (old_password and self.encrypt(old_password) == user.password):
@@ -222,6 +224,14 @@ class UserHandler(BaseHandler):
                                                  {'$set': {'password': self.encrypt(password)}}))
         self.finish({'err': 0})
 
+    @tornado.web.authenticated
+    async def delete(self):
+        if not self.current_user.admin:
+            return self.finish({'err': 1, 'msg': 'unauthorized'})
+
+        await awaitable(self.db.users.delete_one({'_id': ObjectId(self.args._id)}))
+        self.finish({'err': 0})
+
 
 @bp.route("/reset")
 class ResetHandler(BaseHandler):
@@ -285,7 +295,7 @@ class EmailHandler(BaseHandler):
             code = uuid.uuid4().hex
             key = f'{self.prefix}_active_{code}'
             await awaitable(self.rd.setex(key, 600, self.args.email))
-            url = f'https://{self.request.host}/active/{code}'
+            url = f'{self.scheme}://{self.host}/active/{code}'
             content = f'请点击链接或将其复制到地址栏打开: <br><a href="{url}">{url}</a>'
         else:
             return self.finish({'err': 1, 'msg': 'action is not defined'})
