@@ -21,6 +21,7 @@ from .email_utils import AioEmail
 from .email_utils import Email
 from .fire import Fire
 from .http_utils import Chrome
+from .http_utils import patch_connection_pool
 from .http_utils import Request
 from .http_utils import Response
 from .ip_region import Ip2Region
@@ -28,7 +29,6 @@ from .log_utils import Logger
 from .log_utils import WatchedFileHandler
 from .rabbitmq import AioPika
 from .rabbitmq import Pika
-from .redismq import RedisMQ
 from .utils import AioQueue
 from .utils import awaitable
 from .utils import ceil
@@ -58,12 +58,12 @@ warnings.filterwarnings("ignore")
 __all__ = [
     'awaitable', 'floor', 'ceil', 'to_str', 'to_bytes', 'tqdm', 'yaml_load', 'yaml_dump',
     'timeit', 'retry', 'aioretry', 'smart_decorator', 'synchronize', 'cached_property',
-    'get_ip', 'connect', 'ip2int', 'int2ip', 'int2str', 'str2int',
+    'get_ip', 'connect', 'ip2int', 'int2ip', 'int2str', 'str2int', 'patch_connection_pool',
     'Fire', 'Ip2Region', 'Singleton', 'JSONEncoder',
     'Dict', 'DefaultDict', 'DictWrapper', 'DictUnwrapper',
     'Email', 'AioEmail', 'Queue', 'AioQueue',
     'Config', 'Logger', 'WatchedFileHandler',
     'Mongo', 'MongoClient', 'Redis', 'AioRedis', 'Motor', 'MotorClient',
-    'Mysql', 'AioMysql', 'Pika', 'AioPika', 'RedisMQ',
+    'Mysql', 'AioMysql', 'Pika', 'AioPika',
     'Request', 'Response', 'Chrome',
 ]
