@@ -86,7 +86,7 @@ class Config(Dict):
     def _guess(self, params):
         args = {}
         for i, param in enumerate(params):
-            if param.find('=') >= 0:
+            if param.startswith('--') and param.find('=') >= 0:
                 arr = param[2:].split('=')
                 args[arr[0]] = self._convert(arr[1])
             elif param.startswith('--no-'):
