@@ -5,6 +5,7 @@ Author: zhangkai
 Email: zhangkai@cmcm.com
 Last modified: 2018-01-05 11:24:17
 '''
+import asyncio
 import os
 import time
 from urllib.parse import quote_plus
@@ -14,6 +15,7 @@ import aredis
 import pymongo
 import pymysql
 import redis
+from aiomysql.connection import Connection
 from motor import core
 from motor.docstrings import get_database_doc
 from motor.frameworks import asyncio as asyncio_framework
@@ -339,6 +341,20 @@ class Mysql:
             cursor.close()
 
 
+async def _read_bytes(self, num_bytes):
+    try:
+        data = await self._reader.readexactly(num_bytes)
+    except asyncio.exceptions.IncompleteReadError as e:
+        msg = "Lost connection to MySQL server during query"
+        raise pymysql.OperationalError(2013, msg) from e
+    except (IOError, OSError) as e:
+        msg = "Lost connection to MySQL server during query (%s)" % (e,)
+        raise pymysql.OperationalError(2013, msg) from e
+    return data
+
+Connection._read_bytes = _read_bytes
+
+
 class AioMysql(Mysql):
 
     async def reconnect(self):
